c ######################################################################
c #
c #                  HASTELLOY C276 PROPERTIES PACKAGE
c #                  ---------------------------------
c # Contains functions for the calculation of the thermo-physical
c # properties of Hastelloy C276 (Haynes superalloy)
c #
c ######################################################################

c ######################################################################
      real function dHastelloyC276(T)
c ######################################################################
c #
c # Density of Hastelloy C276
c #
c # Range: 0 <= T <= inf K
c #
c #                        References
c #                        ----------
c # J.Lu, E.S. Choi, H.D. Zhou, Physical Properties of Hastelloy(R) 
c # C-276 at cryogenic temperatures, J. Appl. Phys, 103, 064908, 2008
c #
c # variable          I/O    meaning                           units
c # --------------------------------------------------------------------
c #   T               x      absolute temperature              K
c #   dHastelloyC276    x    density                           Kg/m**3
c #
c #
c # Author : L.Bottura at Cryosoft
c # Version: 1.0   December 2012
c #
c ######################################################################
      implicit none
c * external variables
      real     T
c * fit variables      

c * local variables

c *      
      dHastelloyC276 = 8890.0
c *

      return
      end
c ######################################################################
      real function cHastelloyC276(T)
c ######################################################################
c #
c # Density of Hastelloy C276
c #
c # Range: 1 <= T <= 300 K
c #
c #                        References
c #                        ----------
c # J.Lu, E.S. Choi, H.D. Zhou, Physical Properties of Hastelloy(R) 
c # C-276 at cryogenic temperatures, J. Appl. Phys, 103, 064908, 2008
c #
c # variable          I/O    meaning                           units
c # --------------------------------------------------------------------
c #   T               x      absolute temperature              K
c #   cHastelloyC276    x    specific heat                     J/Kg K
c #
c #
c # Author : L.Bottura at Cryosoft
c # Version: 1.0   April 2020
c #
c ######################################################################
      implicit none
c * external variables
      real     T
c * fit variables
      real     AA,BB,CC,DD,a,b,c,d,na,nb,nc,nd
      real     Tmin,Tmax
      data     AA  / 1.818507561  / ,  BB  / 497.9442578 / ,
     &         CC  /-70.23050481  / 
      data     a   /  2.458591837 / ,  b   /  83.34880236 / ,
     &         c   / 40.73099483  / 
      data     na  /  1.416855842 / ,  nb  /  2.337923875 / ,
     &         nc  /  2.320395394 / 
      data     Tmin / 1.0/, Tmax / 300.0/
      save    
c * local variables
      real     TT
c *
      TT=T
      TT=min(TT,Tmax)
      TT=max(TT,Tmin)
      
      cHastelloyC276 = AA*(TT/a)**na/(1+(TT/a)**na) + 
     &                 BB*(TT/b)**nb/(1+(TT/b)**nb) + 
     &                 CC*(TT/c)**nc/(1+(TT/c)**nc)
c *
      return
      end
c ######################################################################
      real function kHastelloyC276(T)
c ######################################################################
c #
c # Thermal conductivity of Hastelloy C276
c #
c # Range: 2 <= T <= 300 K
c #
c #                        References
c #                        ----------
c # J.Lu, E.S. Choi, H.D. Zhou, Physical Properties of Hastelloy(R) 
c # C-276 at cryogenic temperatures, J. Appl. Phys, 103, 064908, 2008
c #
c # variable          I/O    meaning                           units
c # --------------------------------------------------------------------
c #   T               x      absolute temperature              K
c #   kHastelloyC276    x    thermal conductivity              W/m K
c #
c #
c # Author : L.Bottura at Cryosoft
c # Version: 1.0   December 2012
c #
c ######################################################################
      implicit none
c * external variables
      real     T
c * fit variables
      real     p1,p2,p3,p4
      real     Tmin,Tmax
      data     p1  /   0.2093 / ,  p2  / 125.7155 / ,
     &         p3  /  60.0344 / ,  p4  / 2.1669   / 
      data     Tmin / 2.0/, Tmax / 400.0/
      save
c * local variables
      real     TT
c *
      TT=T
      TT=min(TT,Tmax)
      TT=max(TT,Tmin)

      kHastelloyC276 = p1*TT*(1+(TT/p2)**p4) / (1+(TT/p3)**p4)
c *

      return
      end
c ######################################################################
      real function rHastelloyC276(T)
c ######################################################################
c #
c # Electrical resistivity of Hastelloy C276
c #
c # Range: 0 <= T <= 400 K
c #
c #                        References
c #                        ----------
c # J.Lu, E.S. Choi, H.D. Zhou, Physical Properties of Hastelloy(R) 
c # C-276 at cryogenic temperatures, J. Appl. Phys, 103, 064908, 2008
c #
c # variable          I/O    meaning                           units
c # --------------------------------------------------------------------
c #   T               x      absolute temperature              K
c #   rHastelloyC276    x    resistivity                       Ohm m
c #
c # Author : L.Bottura at CryoSoft
c # Version: 1.0   October 2012
c #
c ######################################################################
      implicit none
c * external variables
      real     T
c * fit variables
      real     A,B,C
      real     Tmin,Tmax
      data     A  /  1.22634e-6 / ,  B  / 1.26121e-10 / ,
     &         C  / -2.2417e-14 /
      data     Tmin   / 0.0/, Tmax   / 400.0/
      save
c * local variables
      real     TT

c *
      TT=T
      TT=min(TT,Tmax)
      TT=max(TT,Tmin)

      rHastelloyC276 = A + B*TT + C*TT*TT
	
c *
      return
      end
